[Zope3-checkins] CVS: Zope3/src/zope/app/xml - README.txt:1.6 schemainterface.py:1.2

Philipp von Weitershausen philikon@philikon.de
Fri, 11 Apr 2003 06:52:18 -0400


Update of /cvs-repository/Zope3/src/zope/app/xml
In directory cvs.zope.org:/tmp/cvs-serv8990/xml

Modified Files:
	README.txt schemainterface.py 
Log Message:
Renamed IXMLRepresentable to IXMLSource and updated the documentation
accordingly.


=== Zope3/src/zope/app/xml/README.txt 1.5 => 1.6 ===
--- Zope3/src/zope/app/xml/README.txt:1.5	Thu Apr 10 12:51:00 2003
+++ Zope3/src/zope/app/xml/README.txt	Fri Apr 11 06:52:17 2003
@@ -4,9 +4,9 @@
 
 Short description of the Zope 3 XML Architecture:
 
-  * Framework to represent any object as XML (IXMLRepresentable).
+  * Framework to represent any object as XML (IXMLSource).
 
-  * XML Schema Interfaces. An IXMLRepresentable implements zero or
+  * XML Schema Interfaces. An IXMLSource implements zero or
     more XML Schema Interfaces on a per-instance basis.
 
   * Using XML Schema Interfaces, we can leverage Zope 3's Component
@@ -15,16 +15,16 @@
     another. Multiple adapters can be strung together this way to
     create a pipelined transformation architecture.
 
-  * We can also provide views for XML representable objects based on the
+  * We can also provide views for XML source objects based on the
     schemas they implement, for instance an IXSLTView that uses an
     XSLT stylesheet to provide a presentation in HTML.
 
-IXMLRepresentable
+IXMLSource
 
-  Promises to be adaptable to one of (these are all IXMLRepresentable
-  as well):
+  Promises to be adaptable to one of the following (these are all
+  IXMLSource as well):
 
-    * IXMLText: XML source text
+    * IXMLText: XML text
 
     * IXMLDom: W3C DOM tree.
 
@@ -48,15 +48,15 @@
     * provide an adapter from IInvoiceSchema to IInvoice.
 
     * create a class that implements IInvoice as well as
-      IXMLRepresentable. The only XML this object should represent
-      should be conformant to IInvoiceSchema.
+      IXMLSource. The only XML this object should represent should be
+      conformant to IInvoiceSchema.
 
 Views
 
-  Since XML schema interfaces can be treated like any other interfaces in many
-  ways, we can also define views for them. Using the above example schema, the
-  following browser page would be a view for XMLRepresentables implementing
-  it::
+  Since XML schema interfaces can be treated like any other interfaces
+  in many ways, we can also define views for them. Using the above
+  example schema, the following browser page would be a view for XML
+  sources implementing it::
 
     <browser:page
         name="report.html"


=== Zope3/src/zope/app/xml/schemainterface.py 1.1 => 1.2 ===
--- Zope3/src/zope/app/xml/schemainterface.py:1.1	Thu Apr 10 12:07:45 2003
+++ Zope3/src/zope/app/xml/schemainterface.py	Fri Apr 11 06:52:17 2003
@@ -17,7 +17,7 @@
 """
 
 from zope.interface.interface import InterfaceClass
-from zope.app.interfaces.xml.representable import IXMLRepresentable
+from zope.app.interfaces.xml.source import IXMLSource
 
 class XMLSchemaInterfaceClass(InterfaceClass):
     """
@@ -29,9 +29,9 @@
     def __init__(self, uri):
         doc = """XML Schema based interface
 
     Instances of this interface must be XML representable with XML that conforms
     to the schema: %s""" % uri
-        super(XMLSchemaInterfaceClass, self).__init__(uri, (IXMLRepresentable,),
+        super(XMLSchemaInterfaceClass, self).__init__(uri, (IXMLSource,),
                                                       __doc__=doc)
 
     def __reduce__(self):
@@ -29,9 +29,9 @@
         doc = """XML Schema based interface
 
-    Instances of this interface must be XML representable with XML that conforms
+    Instances of this interface must be an XML source that conforms
     to the schema: %s""" % uri